==> portfolioSim_0.1-1.tar.gz: portfolioSim/man/portfolioSim-package.Rd <==
\name{portfolioSim-package}
\alias{portfolioSim-package}
\alias{portfolioSim}
\docType{package}
\title{
Framework for simulating equity portfolio strategies
}
\description{
Classes that serve as a framework for designing equity
portfolio simulations.
}
\details{
\tabular{ll}{
Package: \tab portfolioSim\cr
Version: \tab 0.1-1\cr
Date: \tab 2006-10-04\cr
Depends: \tab R (>= 2.4.0), methods, lattice, portfolio\cr
License: \tab GPL version 2 or later.\cr
Packaged: \tab Wed Oct 4 13:35:03 2006; enos\cr
Built: \tab R 2.4.0; ; 2006-10-04 14:00:22; unix\cr
}

Index:
\preformatted{
instantData-class       Class "instantData"
loadIn                  Load data from various formats.
orderable-class         Class "orderable"
periodData-class        Class "periodData"
portfolioSim-class      Class "portfolioSim"
portfolioSim-package    Framework for simulating equity portfolio
                        strategies
saveOut                 Save data in various formats.
sdiDf-class             Class "sdiDf"
simData-class           Class "simData"
simDataInterface-class
                        Class "simDataInterface"
simResult-class         Class "simResult"
simResultSinglePeriod-class
                        Class "simResultSinglePeriod"
simSummaryInterface-class
                        Class "simSummaryInterface"
simTrades-class         Class "simTrades"
simTradesInterface-class
                        Class "simTradesInterface"
starmine.sim            StarMine Rankings, 1995, and supplementary
                        data.
stiFromSignal-class     Class "stiFromSignal"
stiPresetTrades-class   Class "stiPresetTrades"
}

Further information is available in the following vignettes:
\tabular{ll}{
\code{portfolioSim} \tab Performing equity investment simulations with the portfolioSim package (source, pdf)\cr
}
}
\author{
Jeff Enos <jeff@kanecap.com> and David Kane <dave@kanecap.com>,
with contributions from Kyle Campbell
<Kyle.W.Campbell@williams.edu>

Maintainer: Jeff Enos <jeff@kanecap.com>
}
\keyword{ package }

==> portfolioSim_0.1-2.tar.gz: portfolioSim/man/portfolioSim-package.Rd <==
\name{portfolioSim-package}
\alias{portfolioSim-package}
\alias{portfolioSim}
\docType{package}
\title{
Framework for simulating equity portfolio strategies
}
\description{
Classes that serve as a framework for designing equity
portfolio simulations.
}
\details{
\tabular{ll}{
Package: \tab portfolioSim\cr
Version: \tab 0.1-2\cr
Date: \tab 2007-01-16\cr
Depends: \tab R (>= 2.4.0), methods, lattice, portfolio (>= 0.3-3)\cr
License: \tab GPL version 2 or later.\cr
Built: \tab R 2.4.1; ; 2007-01-16 13:36:45; unix\cr
}

Index:
\preformatted{
instantData-class       Class "instantData"
loadIn                  Load data from various formats.
orderable-class         Class "orderable"
periodData-class        Class "periodData"
portfolioSim-class      Class "portfolioSim"
portfolioSim-package    Framework for simulating equity portfolio
                        strategies
saveOut                 Save data in various formats.
sdiDf-class             Class "sdiDf"
simData-class           Class "simData"
simDataInterface-class
                        Class "simDataInterface"
simResult-class         Class "simResult"
simResultSinglePeriod-class
                        Class "simResultSinglePeriod"
simSummaryInterface-class
                        Class "simSummaryInterface"
simTrades-class         Class "simTrades"
simTradesInterface-class
                        Class "simTradesInterface"
starmine.sim            StarMine Rankings, 1995, and supplementary
                        data.
stiFromSignal-class     Class "stiFromSignal"
stiPresetTrades-class   Class "stiPresetTrades"
}

Further information is available in the following vignettes:
\tabular{ll}{
\code{portfolioSim} \tab Performing equity investment simulations with the portfolioSim package (source, pdf)\cr
}
}
\author{
Jeff Enos <jeff@kanecap.com> and David Kane <dave@kanecap.com>,
with contributions from Kyle Campbell
<Kyle.W.Campbell@williams.edu>

Maintainer: Jeff Enos <jeff@kanecap.com>
}
\keyword{ package }
